NAME

Poker::Dealer - Simple class to represent a poker dealer

VERSION

Version 0.11

SYNOPSIS

use Poker::Dealer;

my $dealer = Poker::Dealer->new;
my $dealer = Poker::Dealer->new( joker_count => 2 );

$dealer->shuffle_deck;
my $cards = $dealer->deal_up(4);
my $cards = $dealer->deal_named(['As', 'Ah']);
my $joker = $dealer->deal_named(['Jo1']);

shuffle_deck

Creates a new deck and randomizes the cards.

reshuffle

Shuffles cards in the discard pile and adds them to the existing deck.

deal_down

deal_up

deal_named

Fetch a specific set of cards from the deck.

AUTHOR

Nathaniel Graham, <ngraham at cpan.org>

LICENSE AND COPYRIGHT

Copyright 2016 Nathaniel Graham.