NAME
Poker::Hand - Simple class to represent a poker hand.
VERSION
Version 0.11
SYNOPSIS
This class is used internally by Poker::Eval and Poker::Game. You probably don't want to use it directly.
ATTRIBUTES
cards
Array ref of Poker::Card objects.
best_combo
Best combination of cards (hole + community) according to rules of game.
score
Numerical score of best combination (high direction)
name
English name of best high combination
low_score / low_name / low_combo
Optional low-direction result for split-pot games (e.g. Omaha Hi-Lo). Undefined when the hand does not qualify for low.
ev
Expected win rate of hand in given situation
cards_flat
hole cards in human-readable form
best_combo_flat
best combination of cards in human-readable form
AUTHOR
Nathaniel Graham, <ngraham at cpan.org>
LICENSE AND COPYRIGHT
Copyright 2016 Nathaniel Graham.
This program is free software; you can redistribute it and/or modify it under the terms of the the Artistic License (2.0). You may obtain a copy of the full license at: